package com.diagbot.facade;

import com.diagbot.dto.DrugInfoDTO;
import com.diagbot.dto.LisDetailDTO;
import com.diagbot.dto.OperationInfoDTO;
import com.diagbot.dto.RetrievalDTO;
import com.diagbot.repository.*;
import com.diagbot.vo.RetrievalVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.List;

/**
 * @Description:
 * @Author:zhaops
 * @time: 2020/8/12 16:44
 */
@Component
public class RetrievalFacade {

    @Autowired
    LisPackRepository lisPackRepository;

    @Autowired
    LisRepository lisRepository;

    @Autowired
    ICDDiseaseRepository icdDiseaseRepository;

    @Autowired
    PacsRepository pacsRepository;

    @Autowired
    MedicineRepository medicineRepository;

    @Autowired
    OperationRepository operationRepository;

    /**
     * 检索
     *
     * @param retrievalVO
     * @return
     */
    public RetrievalDTO index(RetrievalVO retrievalVO) {
        RetrievalDTO retrievalDTO = new RetrievalDTO();

        switch (retrievalVO.getType()) {
            case 1:
                retrievalDTO.setLisNames(getLisPacks(retrievalVO.getInputStr()));
                break;
            case 2:
                retrievalDTO.setLisDetailNames(getLis(retrievalVO.getInputStr()));
                break;
            case 3:
                retrievalDTO.setPacsNames(getPACSs(retrievalVO.getInputStr()));
                break;
            case 4:
                retrievalDTO.setDiseaseNames(getDiseases(retrievalVO.getInputStr()));
                break;
            case 5:
                retrievalDTO.setDrugNames(getMedicines(retrievalVO.getInputStr()));
                break;
            case 6:
                retrievalDTO.setOperationNames(getOperations(retrievalVO.getInputStr()));
                break;
        }

        return retrievalDTO;
    }


    /*
     * 获取化验套餐名称列表
     */
    public List<String> getLisPacks(String name) {

        LisPackNode lisPackNode = new LisPackNode();
        List<String> lisPacklist = lisPackNode.getLISPackNameList(name,lisPackRepository);

        return lisPacklist;
    }


    /*
     * 获取化验细项名称列表
     */
    public List<LisDetailDTO> getLis(String name) {

        LisNode lisNode = new LisNode();
        List<LisDetailDTO> lislist = lisNode.getLisDetailList(name,lisRepository);

        return lislist;
    }


    /*
     * 获取辅检名称列表
     */
    public List<String> getPACSs(String name) {

        PACSNode pacsNode = new PACSNode();
        List<String> pacslist = pacsNode.getPACSNameList(name,pacsRepository);

        return pacslist;
    }


    /*
     * 获取疾病名称列表
     */
    public List<String> getDiseases(String name) {

        ICDDiseaseNode diseaseNode = new ICDDiseaseNode();
        List<String> diseaselist = diseaseNode.getDiseaseNameList(name,icdDiseaseRepository);

        return diseaselist;
    }


    /*
     * 获取药品商品名称列表
     */
    public List<DrugInfoDTO> getMedicines(String name) {

        MedicineNode medicineNode = new MedicineNode();
        List<DrugInfoDTO> medslist = medicineNode.getMedicineList(name,medicineRepository);

        return medslist;
    }


    /*
     * 获取手术和操作名称列表
     */
    public List<OperationInfoDTO> getOperations(String name) {

        OperationNode operationNode = new OperationNode();
        List<OperationInfoDTO> opslist = operationNode.getOperationList(name,operationRepository);

        return opslist;
    }
}